==> connect-sdk-16.0.tar.gz: connect-sdk-16.0/connect/models/__init__.py <==
# -*- coding: utf-8 -*-

# This file is part of the Ingram Micro Cloud Blue Connect SDK.
# Copyright (c) 2019 Ingram Micro. All Rights Reserved.

from .activation_response import ActivationTemplateResponse, ActivationTileResponse
from .asset import Asset
from .base import BaseModel
from .company import Company, User
from .connection import Connection
from .contact import Contact, ContactInfo, PhoneNumber
from .conversation import Conversation, ConversationMessage
from .event import EventInfo, Events
from .fulfillment import Fulfillment
from .hub import Hub, HubInstance, ExtIdHub, HubStats
from .marketplace import Activation, Agreement, AgreementStats, Contract, Marketplace
from .parameters import Constraints, Param, ValueChoice
from .product import CustomerUiSettings, Document, DownloadLink, Item, Product, \
    ProductConfiguration, Renewal
from .server_error_response import ServerErrorResponse
from .tier_config import Template, TierAccount, TierAccounts, TierConfig, TierConfigRequest
from .usage import UsageFile, UsageListing, UsageRecord, UsageRecords

__all__ = [
    'Activation',
    'ActivationTemplateResponse',
    'ActivationTileResponse',
    'Agreement',
    'AgreementStats',
    'Asset',
    'BaseModel',
    'Company',
    'Connection',
    'Constraints',
    'Contact',
    'ContactInfo',
    'Contract',
    'Conversation',
    'ConversationMessage',
    'CustomerUiSettings',
    'Document',
    'DownloadLink',
    'EventInfo',
    'Events',
    'ExtIdHub',
    'Fulfillment',
    'Hub',
    'HubInstance',
    'HubStats',
    'Item',
    'Marketplace',
    'Param',
    'PhoneNumber',
    'Product',
    'ProductConfiguration',
    'Renewal',
    'ServerErrorResponse',
    'Template',
    'TierAccount',
    'TierAccounts',
    'TierConfig',
    'TierConfigRequest',
    'UsageFile',
    'UsageListing',
    'UsageRecord',
    'UsageRecords',
    'User',
    'ValueChoice',
]

==> connect-sdk-17.0.tar.gz: connect-sdk-17.0/connect/models/__init__.py <==
# -*- coding: utf-8 -*-

# This file is part of the Ingram Micro Cloud Blue Connect SDK.
# Copyright (c) 2019 Ingram Micro. All Rights Reserved.

from .activation_response import ActivationTemplateResponse, ActivationTileResponse
from .asset import Asset
from .base import BaseModel
from .company import Company, User
from .connection import Connection
from .contact import Contact, ContactInfo, PhoneNumber
from .conversation import Conversation, ConversationMessage
from .event import EventInfo, Events
from .fulfillment import Fulfillment
from .hub import Hub, HubInstance, ExtIdHub, HubStats
from .marketplace import Activation, Agreement, AgreementStats, Contract, Marketplace
from .parameters import Constraints, Param, ValueChoice
from .product import CustomerUiSettings, Document, DownloadLink, Item, Product, \
    ProductCategory, ProductConfiguration, ProductFamily, ProductStats, ProductStatsInfo, Renewal
from .server_error_response import ServerErrorResponse
from .tier_config import Configuration, Template, TierAccount, TierAccounts, TierConfig, \
    TierConfigRequest
from .usage import UsageFile, UsageListing, UsageRecord, UsageRecords

__all__ = [
    'Activation',
    'ActivationTemplateResponse',
    'ActivationTileResponse',
    'Agreement',
    'AgreementStats',
    'Asset',
    'BaseModel',
    'Company',
    'Configuration',
    'Connection',
    'Constraints',
    'Contact',
    'ContactInfo',
    'Contract',
    'Conversation',
    'ConversationMessage',
    'CustomerUiSettings',
    'Document',
    'DownloadLink',
    'EventInfo',
    'Events',
    'ExtIdHub',
    'Fulfillment',
    'Hub',
    'HubInstance',
    'HubStats',
    'Item',
    'Marketplace',
    'Param',
    'PhoneNumber',
    'Product',
    'ProductCategory',
    'ProductConfiguration',
    'ProductFamily',
    'ProductStats',
    'ProductStatsInfo',
    'Renewal',
    'ServerErrorResponse',
    'Template',
    'TierAccount',
    'TierAccounts',
    'TierConfig',
    'TierConfigRequest',
    'UsageFile',
    'UsageListing',
    'UsageRecord',
    'UsageRecords',
    'User',
    'ValueChoice',
]
